@@ -4,7 +4,7 @@
  * GAP ... Gimp Animation Plugins
  *
  * This Module contains:
- * modify Layer(s) in frames dialog 
+ * modify Layer(s) in frames dialog
  * (perform actions (like raise, set visible, apply filter)
  *               - foreach selected layer
  *               - in each frame of the selected framerange)
@@ -66,7 +66,40 @@
 
 extern      int gap_debug; /* ==0  ... dont print debug infos */
 
+static void p_mod_frames_response (GtkWidget *widget,
+                 gint       response_id,
+                 GapModFramesGlobalParams *gmop);
+static void p_upd_sensitivity(GapModFramesGlobalParams *gmop);
+static void p_func_optionmenu_callback  (GtkWidget     *wgt_item,
+                           GapModFramesGlobalParams *gmop);
+static void p_make_func_menu_item(const char *title
+                    , const char *tip_text
+		    , gint32 action_mode
+		    , GtkWidget *menu
+		    , GapModFramesGlobalParams *gmop
+		    );
 
+static void p_make_func_menu_item_set_mode(const char *mode_name
+		    , gint32 action_mode
+		    , GtkWidget *menu
+		    , GapModFramesGlobalParams *gmop
+		    );
+
+
+static void p_make_layer_attrinutes_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+static void p_make_layer_modes_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+static void p_make_layer_stackpositions_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+static void p_make_merge_layers_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+static void p_make_selection_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+static void p_make_layermask_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+static void p_make_toplevel_menu_items(GtkWidget *master_menu, GapModFramesGlobalParams *gmop);
+
+static void p_case_sensitive_toggled_callback(GtkCheckButton *checkbutton, GapModFramesGlobalParams *gmop);
+static void p_invert_selection_toggled_callback(GtkCheckButton *checkbutton, GapModFramesGlobalParams *gmop);
+static void p_layer_pattern_entry_update_cb(GtkWidget *widget, GapModFramesGlobalParams *gmop);
+static void p_new_layername_entry_update_cb(GtkWidget *widget, GapModFramesGlobalParams *gmop);
+static void p_sel_mode_radio_callback(GtkWidget *widget, GapModFramesGlobalParams *gmop);
+static void p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop);
 
 
 /* ---------------------------------
@@ -118,7 +151,7 @@ p_upd_sensitivity(GapModFramesGlobalParams *gmop)
     case GAP_MTCH_START:
     case GAP_MTCH_END:
     case GAP_MTCH_ANYWHERE:
-      /* insensitive for other select modes that are 
+      /* insensitive for other select modes that are
        * lists of stacknumbers or all_visible layers
        */
       l_sensitive = TRUE;
@@ -145,7 +178,7 @@ p_upd_sensitivity(GapModFramesGlobalParams *gmop)
   }
 
 
-  
+
   l_sensitive = FALSE;
   l_sensitive_frame = TRUE;
   l_label_name = " ";
@@ -171,7 +204,7 @@ p_upd_sensitivity(GapModFramesGlobalParams *gmop)
       break;
     case GAP_MOD_ACM_SEL_REPLACE:
     case GAP_MOD_ACM_SEL_ADD:
-    case GAP_MOD_ACM_SEL_SUTRACT:
+    case GAP_MOD_ACM_SEL_SUBTRACT:
     case GAP_MOD_ACM_SEL_INTERSECT:
     case GAP_MOD_ACM_SEL_NONE:
     case GAP_MOD_ACM_SEL_ALL:
@@ -181,7 +214,7 @@ p_upd_sensitivity(GapModFramesGlobalParams *gmop)
     default:
       break;
   }
- 
+
   wgt = gmop->new_layername_entry;
   if(wgt)
   {
@@ -200,7 +233,7 @@ p_upd_sensitivity(GapModFramesGlobalParams *gmop)
     gtk_label_set_text(GTK_LABEL(wgt), l_label_name);
   }
 
-  
+
 }  /* end p_upd_sensitivity */
 
 
@@ -232,12 +265,12 @@ p_func_optionmenu_callback  (GtkWidget     *wgt_item,
  }
 
  gmop->action_mode = l_idx;
- 
+
  if(title)
  {
    if(gmop->func_info_label)
    {
-     gtk_label_set_text(GTK_LABEL(gmop->func_info_label), title);    
+     gtk_label_set_text(GTK_LABEL(gmop->func_info_label), title);
    }
 
  }
@@ -263,7 +296,7 @@ p_make_func_menu_item(const char *title
 		    )
 {
   GtkWidget *menu_item;
-  
+
   menu_item = gtk_menu_item_new_with_label (title);
         g_signal_connect (G_OBJECT (menu_item), "activate",
                           G_CALLBACK (p_func_optionmenu_callback),
@@ -276,16 +309,521 @@ p_make_func_menu_item(const char *title
                           , (gpointer)tip_text);
   gtk_widget_show (menu_item);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-  
+
   if(action_mode == gmop->action_mode)
   {
     if(gmop->func_info_label)
     {
-      gtk_label_set_text(GTK_LABEL(gmop->func_info_label), title);    
+      gtk_label_set_text(GTK_LABEL(gmop->func_info_label), title);
     }
   }
 }  /* end p_make_func_menu_item */
 
+
+
+/* -------------------------------
+ * p_make_layer_attrinutes_submenu
+ * -------------------------------
+ */
+static void
+p_make_layer_attrinutes_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  GtkWidget *menu_item;
+  GtkWidget *sub_menu;
+
+  /* the Layer Attributes sub menu */
+  menu_item = gtk_menu_item_new_with_label (_("Layer Attributes"));
+  gtk_widget_show (menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
+
+  sub_menu = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
+
+  p_make_func_menu_item(_("Set layer(s) visible")
+                       ,_("set all selected layers visible")
+		       ,GAP_MOD_ACM_SET_VISIBLE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Set layer(s) invisible")
+                       ,_("set all selected layers invisible")
+		       ,GAP_MOD_ACM_SET_INVISIBLE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Set layer(s) linked")
+                       ,_("set all selected layers linked")
+		       ,GAP_MOD_ACM_SET_LINKED
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Set layer(s) unlinked")
+                       ,_("set all selected layers unlinked")
+		       ,GAP_MOD_ACM_SET_UNLINKED
+		       ,sub_menu
+		       ,gmop
+		       );
+
+}  /* end p_make_layer_attrinutes_submenu */
+
+
+/* ------------------------------
+ * p_make_func_menu_item_set_mode
+ * ------------------------------
+ */
+static void
+p_make_func_menu_item_set_mode(const char *mode_name
+		    , gint32 action_mode
+		    , GtkWidget *menu
+		    , GapModFramesGlobalParams *gmop)
+{
+  char *title;
+  char *tip_text;
+
+  title = g_strdup_printf(_("Set layer(s) mode: %s"), mode_name);
+  tip_text = g_strdup_printf(_("Set all selected layers to mode: %s"), mode_name);
+
+  p_make_func_menu_item(title
+           ,tip_text
+           ,action_mode
+           ,menu
+           ,gmop
+           );
+  g_free(title);
+  g_free(tip_text);
+}  /* end p_make_func_menu_item_set_mode */
+
+/* ------------------------------
+ * p_make_layer_modes_submenu
+ * ------------------------------
+ */
+static void
+p_make_layer_modes_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  GtkWidget *menu_item;
+  GtkWidget *sub_menu;
+  /* the Layer Modes sub menu */
+  menu_item = gtk_menu_item_new_with_label (_("Layer Modes"));
+  gtk_widget_show (menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
+
+  sub_menu = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
+
+
+  p_make_func_menu_item_set_mode(_("Normal")
+           ,GAP_MOD_ACM_SET_MODE_NORMAL
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Dissolve")
+           ,GAP_MOD_ACM_SET_MODE_DISSOLVE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Multiply")
+           ,GAP_MOD_ACM_SET_MODE_MULTIPLY
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Divide")
+           ,GAP_MOD_ACM_SET_MODE_DIVIDE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Screen")
+           ,GAP_MOD_ACM_SET_MODE_SCREEN
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Overlay")
+           ,GAP_MOD_ACM_SET_MODE_OVERLAY
+           ,sub_menu
+           ,gmop
+           );
+
+  p_make_func_menu_item_set_mode(_("Difference")
+           ,GAP_MOD_ACM_SET_MODE_DIFFERENCE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Addition")
+           ,GAP_MOD_ACM_SET_MODE_ADDITION
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Subtract")
+           ,GAP_MOD_ACM_SET_MODE_SUBTRACT
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Darken only")
+           ,GAP_MOD_ACM_SET_MODE_DARKEN_ONLY
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Lighten only")
+           ,GAP_MOD_ACM_SET_MODE_LIGHTEN_ONLY
+           ,sub_menu
+           ,gmop
+           );
+
+  p_make_func_menu_item_set_mode(_("Dodge")
+           ,GAP_MOD_ACM_SET_MODE_DODGE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Burn")
+           ,GAP_MOD_ACM_SET_MODE_BURN
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Hardlight")
+           ,GAP_MOD_ACM_SET_MODE_HARDLIGHT
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Softlight")
+           ,GAP_MOD_ACM_SET_MODE_SOFTLIGHT
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Color erase")
+           ,GAP_MOD_ACM_SET_MODE_COLOR_ERASE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Grain extract")
+           ,GAP_MOD_ACM_SET_MODE_GRAIN_EXTRACT_MODE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Grain merge")
+           ,GAP_MOD_ACM_SET_MODE_GRAIN_MERGE_MODE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Hue")
+           ,GAP_MOD_ACM_SET_MODE_HUE_MODE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Saturation")
+           ,GAP_MOD_ACM_SET_MODE_SATURATION_MODE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Color")
+           ,GAP_MOD_ACM_SET_MODE_COLOR_MODE
+           ,sub_menu
+           ,gmop
+           );
+  p_make_func_menu_item_set_mode(_("Value")
+           ,GAP_MOD_ACM_SET_MODE_VALUE_MODE
+           ,sub_menu
+           ,gmop
+           );
+}  /* end p_make_layer_modes_submenu */
+
+
+
+/* -----------------------------------
+ * p_make_layer_stackpositions_submenu
+ * -----------------------------------
+ */
+static void
+p_make_layer_stackpositions_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  GtkWidget *menu_item;
+  GtkWidget *sub_menu;
+
+  /* the Layer Stackposition sub menu */
+  menu_item = gtk_menu_item_new_with_label (_("Layer Stackposition"));
+  gtk_widget_show (menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
+
+  sub_menu = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
+
+  p_make_func_menu_item(_("Raise layer(s)")
+                       ,_("raise all selected layers")
+		       ,GAP_MOD_ACM_RAISE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Lower layer(s)")
+                       ,_("lower all selected layers")
+		       ,GAP_MOD_ACM_LOWER
+		       ,sub_menu
+		       ,gmop
+		       );
+}  /* end p_make_layer_stackpositions_submenu */
+
+
+/* ------------------------------
+ * p_make_merge_layers_submenu
+ * ------------------------------
+ */
+static void
+p_make_merge_layers_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  GtkWidget *menu_item;
+  GtkWidget *sub_menu;
+
+  /* the Merge Layers sub menu */
+  menu_item = gtk_menu_item_new_with_label (_("Merge Layers"));
+  gtk_widget_show (menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
+
+  sub_menu = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
+
+  p_make_func_menu_item(_("Merge layer(s); expand as necessary")
+                       ,_("merge selected layers and expand as necessary")
+		       ,GAP_MOD_ACM_MERGE_EXPAND
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Merge layer(s) clipped to image")
+                       ,_("merge selected layers and clip to image")
+		       ,GAP_MOD_ACM_MERGE_IMG
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Merge layer(s) clipped to bg-layer")
+                       ,_("merge selected layers and clip to bg-layer")
+		       ,GAP_MOD_ACM_MERGE_BG
+		       ,sub_menu
+		       ,gmop
+		       );
+
+}  /* end p_make_merge_layers_submenu */
+
+
+/* ------------------------------
+ * p_make_selection_submenu
+ * ------------------------------
+ */
+static void
+p_make_selection_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  GtkWidget *menu_item;
+  GtkWidget *sub_menu;
+
+  /* the Selection sub menu */
+  menu_item = gtk_menu_item_new_with_label (_("Selection"));
+  gtk_widget_show (menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
+
+  sub_menu = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
+
+  p_make_func_menu_item(_("Replace selection (source is the active frame)")
+                       ,_("Replace Selection by Selection of the invoking Frame Image")
+		       ,GAP_MOD_ACM_SEL_REPLACE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Add selection (source is the active frame)")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_ADD
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Subtract selection (source is the active frame)")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_SUBTRACT
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Intersect selection (source is the active frame)")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_INTERSECT
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Selection none")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_NONE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Selection all")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_ALL
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Selection invert")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_INVERT
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Selection from alpha channel (individual per frame)")
+                       ,NULL
+                       ,GAP_MOD_ACM_SEL_ALPHA
+                       ,sub_menu
+                       ,gmop
+                       );
+  p_make_func_menu_item(_("Save selection to channel (individual per frame)")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_SAVE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Load selection from channel (individual per frame)")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_LOAD
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Delete channel (by name)")
+                       ,NULL
+		       ,GAP_MOD_ACM_SEL_DELETE
+		       ,sub_menu
+		       ,gmop
+		       );
+}  /* end p_make_selection_submenu */
+
+
+/* ------------------------------
+ * p_make_layermask_submenu
+ * ------------------------------
+ */
+static void
+p_make_layermask_submenu(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  GtkWidget *menu_item;
+  GtkWidget *sub_menu;
+
+  /* the LayerMask sub menu */
+  menu_item = gtk_menu_item_new_with_label (_("Layer Mask"));
+  gtk_widget_show (menu_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
+
+  sub_menu = gtk_menu_new ();
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
+
+  p_make_func_menu_item(_("Add white layermask (opaque)")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_WHITE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Add black layermask (transparent)")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_BLACK
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Add layermask from alpha")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_ALPHA
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Add layermask transfer from alpha")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_TALPHA
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Add layermask from selection")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_SEL
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Add layermask from bw copy")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_BWCOPY
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Invert existing layermask")
+                       ,NULL
+                       ,GAP_MOD_ACM_LMASK_INVERT
+                       ,sub_menu
+                       ,gmop
+                       );
+  p_make_func_menu_item(_("Apply filter on layermask")
+                       ,NULL
+		       ,GAP_MOD_ACM_APPLY_FILTER_ON_LAYERMASK
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Delete layermask")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_DELETE
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Apply layermask")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_APPLY
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Copy layermask from layer above")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_COPY_FROM_UPPER_LMASK
+		       ,sub_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Copy layermask from layer below")
+                       ,NULL
+		       ,GAP_MOD_ACM_LMASK_COPY_FROM_LOWER_LMASK
+		       ,sub_menu
+		       ,gmop
+		       );
+}  /* end p_make_layermask_submenu */
+
+
+/* ------------------------------
+ * p_make_toplevel_menu_items
+ * ------------------------------
+ */
+static void
+p_make_toplevel_menu_items(GtkWidget *master_menu, GapModFramesGlobalParams *gmop)
+{
+  /* apply filter has no sub_menu */
+  p_make_func_menu_item(_("Apply filter on layer(s)")
+                       ,_("apply filter to all selected layers")
+		       ,GAP_MOD_ACM_APPLY_FILTER
+		       ,master_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Duplicate layer(s)")
+                       ,NULL
+		       ,GAP_MOD_ACM_DUPLICATE
+		       ,master_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Delete layer(s)")
+                       ,NULL
+		       ,GAP_MOD_ACM_DELETE
+		       ,master_menu
+		       ,gmop
+		       );
+  p_make_func_menu_item(_("Rename layer(s)")
+                       ,NULL
+		       ,GAP_MOD_ACM_RENAME
+		       ,master_menu
+		       ,gmop
+		       );
+
+  p_make_func_menu_item(_("Add alpha channel")
+                       ,NULL
+		       ,GAP_MOD_ACM_ADD_ALPHA
+		       ,master_menu
+		       ,gmop
+		       );
+}  /* end p_make_toplevel_menu_items */
+
+
+
+
 /* ---------------------------------
  * p_case_sensitive_toggled_callback
  * ---------------------------------
@@ -338,7 +876,7 @@ p_layer_pattern_entry_update_cb(GtkWidget *widget, GapModFramesGlobalParams *gmo
   {
     return;
   }
-  
+
   g_snprintf(gmop->sel_pattern, sizeof(gmop->sel_pattern), "%s"
             , gtk_entry_get_text(GTK_ENTRY(widget))
 	    );
@@ -355,7 +893,7 @@ p_new_layername_entry_update_cb(GtkWidget *widget, GapModFramesGlobalParams *gmo
   {
     return;
   }
-  
+
   g_snprintf(gmop->new_layername, sizeof(gmop->new_layername), "%s"
             , gtk_entry_get_text(GTK_ENTRY(widget))
 	    );
@@ -406,10 +944,9 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
   GtkWidget *menu_bar;
   GtkWidget *menu_item;
   GtkWidget *master_menu;
-  GtkWidget *sub_menu;
   gint       row;
   GtkObject *adj;
- 
+
   GtkWidget *radio_button;
   GSList    *radio_group = NULL;
   gboolean  l_radio_pressed;
@@ -496,266 +1033,16 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
   gtk_menu_shell_append(GTK_MENU_SHELL(menu_bar), menu_item);
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item), master_menu);
 
-
-  /* the Layer Attributes sub menu */
-  menu_item = gtk_menu_item_new_with_label (_("Layer Attributes"));
-  gtk_widget_show (menu_item);
-  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
-
-  sub_menu = gtk_menu_new ();
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
-
-  p_make_func_menu_item(_("Set layer(s) visible")
-                       ,_("set all selected layers visible")
-		       ,GAP_MOD_ACM_SET_VISIBLE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Set layer(s) invisible")
-                       ,_("set all selected layers invisible")
-		       ,GAP_MOD_ACM_SET_INVISIBLE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Set layer(s) linked")
-                       ,_("set all selected layers linked")
-		       ,GAP_MOD_ACM_SET_LINKED
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Set layer(s) unlinked")
-                       ,_("set all selected layers unlinked")
-		       ,GAP_MOD_ACM_SET_UNLINKED
-		       ,sub_menu
-		       ,gmop
-		       );
-
-
-
-  /* the Layer Stackposition sub menu */
-  menu_item = gtk_menu_item_new_with_label (_("Layer Stackposition"));
-  gtk_widget_show (menu_item);
-  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
-
-  sub_menu = gtk_menu_new ();
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
-
-  p_make_func_menu_item(_("Raise layer(s)")
-                       ,_("raise all selected layers")
-		       ,GAP_MOD_ACM_RAISE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Lower layer(s)")
-                       ,_("lower all selected layers")
-		       ,GAP_MOD_ACM_LOWER
-		       ,sub_menu
-		       ,gmop
-		       );
-
-
-  /* the Merge Layers sub menu */
-  menu_item = gtk_menu_item_new_with_label (_("Merge Layers"));
-  gtk_widget_show (menu_item);
-  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
-
-  sub_menu = gtk_menu_new ();
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
-
-  p_make_func_menu_item(_("Merge layer(s) expand as necessary")
-                       ,_("merge selected layers and expand as necessary")
-		       ,GAP_MOD_ACM_MERGE_EXPAND
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Merge layer(s) clipped to image")
-                       ,_("merge selected layers and clip to image")
-		       ,GAP_MOD_ACM_MERGE_IMG
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Merge layer(s) clipped to bg-layer")
-                       ,_("merge selected layers and clip to bg-layer")
-		       ,GAP_MOD_ACM_MERGE_BG
-		       ,sub_menu
-		       ,gmop
-		       );
-
-  /* the Selection sub menu */
-  menu_item = gtk_menu_item_new_with_label (_("Selection"));
-  gtk_widget_show (menu_item);
-  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
-
-  sub_menu = gtk_menu_new ();
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
-
-  p_make_func_menu_item(_("Replace selection (source is the active frame)")
-                       ,_("Replace Selection by Selection of the invoking Frame Image")
-		       ,GAP_MOD_ACM_SEL_REPLACE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Add selection (source is the active frame)")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_ADD
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Subtract selection (source is the active frame)")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_SUTRACT
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Intersect selection (source is the active frame)")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_INTERSECT
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Selection none")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_NONE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Selection all")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_ALL
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Selection invert")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_INVERT
-		       ,sub_menu
-		       ,gmop
-		       );
-
-  p_make_func_menu_item(_("Save selection to channel (individual per frame)")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_SAVE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Load selection from channel (individual per frame)")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_LOAD
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Delete channel (by name)")
-                       ,NULL
-		       ,GAP_MOD_ACM_SEL_DELETE
-		       ,sub_menu
-		       ,gmop
-		       );
-
-  /* the LayerMask sub menu */
-  menu_item = gtk_menu_item_new_with_label (_("Layer Mask"));
-  gtk_widget_show (menu_item);
-  gtk_menu_shell_append (GTK_MENU_SHELL (master_menu), menu_item);
-
-  sub_menu = gtk_menu_new ();
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), sub_menu);
-
-  p_make_func_menu_item(_("Add white layermask (opaque)")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_WHITE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Add black layermask (transparent)")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_BLACK
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Add layermask from alpha")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_ALPHA
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Add layermask transfer from alpha")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_TALPHA
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Add layermask from selection")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_SEL
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Add layermask from bw copy")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_BWCOPY
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Delete layermask")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_DELETE
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Apply layermask")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_APPLY
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Copy layermask from layer above")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_COPY_FROM_UPPER_LMASK
-		       ,sub_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Copy layermask from layer below")
-                       ,NULL
-		       ,GAP_MOD_ACM_LMASK_COPY_FROM_LOWER_LMASK
-		       ,sub_menu
-		       ,gmop
-		       );
-
+  /* make submenus */
+  p_make_layer_attrinutes_submenu(master_menu, gmop);
+  p_make_layer_modes_submenu(master_menu, gmop);
+  p_make_layer_stackpositions_submenu(master_menu, gmop);
+  p_make_merge_layers_submenu(master_menu, gmop);
+  p_make_selection_submenu(master_menu, gmop);
+  p_make_layermask_submenu(master_menu, gmop);
 
   /* finally we have some menu items that are not grouped into sub-menus */
-  /* apply filter has no sub_menu */
-  p_make_func_menu_item(_("Apply filter on layer(s)")
-                       ,_("apply filter to all selected layers")
-		       ,GAP_MOD_ACM_APPLY_FILTER
-		       ,master_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Duplicate layer(s)")
-                       ,NULL
-		       ,GAP_MOD_ACM_DUPLICATE
-		       ,master_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Delete layer(s)")
-                       ,NULL
-		       ,GAP_MOD_ACM_DELETE
-		       ,master_menu
-		       ,gmop
-		       );
-  p_make_func_menu_item(_("Rename layer(s)")
-                       ,NULL
-		       ,GAP_MOD_ACM_RENAME
-		       ,master_menu
-		       ,gmop
-		       );
-
-  p_make_func_menu_item(_("Add alpha channel")
-                       ,NULL
-		       ,GAP_MOD_ACM_ADD_ALPHA
-		       ,master_menu
-		       ,gmop
-		       );
- 
- 
+  p_make_toplevel_menu_items(master_menu, gmop);
 
 
   row++;
@@ -836,7 +1123,7 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
   g_signal_connect ( G_OBJECT (check_button), "toggled",
 		     G_CALLBACK (p_case_sensitive_toggled_callback),
 		     gmop);
- 
+
   row++;
 
   /* the radio button "Pattern is start of layer name"  */
@@ -859,7 +1146,7 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
   g_signal_connect ( G_OBJECT (radio_button), "toggled",
 		     G_CALLBACK (p_sel_mode_radio_callback),
 		     gmop);
-  
+
   /* the invert layer_selection  check_button */
   check_button = gtk_check_button_new_with_label (_("Invert Layer Selection"));
   gmop->invert_check_button = check_button;
@@ -923,7 +1210,7 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
 		     gmop);
 
   row++;
-  
+
   /* the  radio button "Pattern is a list of layerstack numbers" */
   radio_button = gtk_radio_button_new_with_label ( radio_group, _("Pattern is a list of layerstack numbers") );
   radio_group = gtk_radio_button_get_group ( GTK_RADIO_BUTTON (radio_button) );
@@ -1015,7 +1302,7 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
   g_signal_connect(G_OBJECT(entry), "changed",
 		   G_CALLBACK (p_layer_pattern_entry_update_cb),
 		   gmop);
- 
+
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 4);
 
@@ -1085,14 +1372,14 @@ p_create_mod_frames_dialog(GapModFramesGlobalParams *gmop)
 
   gtk_widget_show(main_vbox);
 
-}  /* end p_create_mod_frames_dialog */ 
+}  /* end p_create_mod_frames_dialog */
 
 
 /* -----------------------------
  * gap_mod_frames_dialog
  * -----------------------------
  */
-int 
+int
 gap_mod_frames_dialog(GapAnimInfo *ainfo_ptr,
                    gint32 *range_from,  gint32 *range_to,
                    gint32 *action_mode, gint32 *sel_mode,
@@ -1103,7 +1390,7 @@ gap_mod_frames_dialog(GapAnimInfo *ainfo_ptr,
   GapModFramesGlobalParams *gmop;
 
   if(gap_debug) printf("\nSTART gap_mod_frames_dialog\n");
-  
+
   gmop = &global_modify_params;
   gimp_ui_init ("gap_mod_frames", FALSE);
   gap_stock_init();
@@ -1119,15 +1406,15 @@ gap_mod_frames_dialog(GapAnimInfo *ainfo_ptr,
   gmop->sel_pattern[0] = '0';
   gmop->sel_pattern[1] = '\0';
   gmop->new_layername[0] = '\0';
- 
+
   gmop->case_sensitive_check_button = NULL;
   gmop->invert_check_button = NULL;
   gmop->layer_pattern_entry = NULL;
   gmop->new_layername_entry = NULL;
   gmop->new_layername_label = NULL;
   gmop->layer_selection_frame = NULL;
- 
-  
+
+
   p_create_mod_frames_dialog(gmop);
   p_upd_sensitivity(gmop);
   gtk_widget_show (gmop->shell);
