@@ -50,11 +50,12 @@
  */
 
 /* SYTEM (UNIX) includes */
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 
+#include <glib/gstdio.h>
+
 /* GIMP includes */
 #include "gtk/gtk.h"
 #include "config.h"
@@ -214,8 +215,8 @@ int p_mpege_info(GapAnimInfo *ainfo_ptr, char *errlist, GapMpegEncoderType encod
   l_idx++;
 
   gap_arr_arg_init(&argv[l_idx], GAP_ARR_WGT_LABEL_LEFT);
-  argv[l_idx].label_txt = _("\nINFORMATINON:\n"
-                            "For more efficient MPEG encoding use the menu:\n"
+  argv[l_idx].label_txt = _("\nNOTE:\n"
+                            "For more efficient MPEG encoding, use the menu:\n"
                             "Video->Encode->Master Videoencoder");
 #endif
 
@@ -382,7 +383,7 @@ int p_mpege_dialog(GapAnimInfo *ainfo_ptr, t_mpg_par *mp_ptr, GapMpegEncoderType
 
      gap_arr_arg_init(&argv[5], GAP_ARR_WGT_TOGGLE);
      argv[5].label_txt = _("Constant Bitrate:");
-     argv[5].help_txt  = _("Iqnore I/P/QSCALE values and use constant bit-rate)");
+     argv[5].help_txt  = _("Ignore I/P/QSCALE values and use constant bit-rate");
      argv[5].int_ret   = 1;
      argv[5].has_default = TRUE;
      argv[5].int_default = 1;
@@ -591,7 +592,7 @@ int p_mpeg2encode_gen_parfile(GapAnimInfo *ainfo_ptr, t_mpg_par *mp_ptr)
   char  *l_basename_ptr;
   char   l_basename_buff[1024];
 
-  l_fp = fopen(mp_ptr->parfile, "w");
+  l_fp = g_fopen(mp_ptr->parfile, "w");
   if(l_fp == NULL)
   {
      fprintf(stderr, "cant open MPEG Paramfile %s for write\n", mp_ptr->parfile);
@@ -707,7 +708,7 @@ int p_mpeg2encode_gen_parfile(GapAnimInfo *ainfo_ptr, t_mpg_par *mp_ptr)
 
   /* generate a startscript */
 
-  l_fp = fopen(mp_ptr->startscript, "w");
+  l_fp = g_fopen(mp_ptr->startscript, "w");
   if(l_fp == NULL)
   {
      fprintf(stderr, "cant open Startscript %s for write\n", mp_ptr->startscript);
@@ -740,7 +741,7 @@ int p_mpeg_encode_gen_parfile(GapAnimInfo *ainfo_ptr, t_mpg_par *mp_ptr)
   char   l_basename_buff[1024];
   char  *l_base_file_format;
 
-  l_fp = fopen(mp_ptr->parfile, "w");
+  l_fp = g_fopen(mp_ptr->parfile, "w");
   if(l_fp == NULL)
   {
      fprintf(stderr, "cant open MPEG Paramfile %s for write\n", mp_ptr->parfile);
@@ -960,7 +961,7 @@ int p_mpeg_encode_gen_parfile(GapAnimInfo *ainfo_ptr, t_mpg_par *mp_ptr)
 
   /* generate a startscript */
 
-  l_fp = fopen(mp_ptr->startscript, "w");
+  l_fp = g_fopen(mp_ptr->startscript, "w");
   if(l_fp == NULL)
   {
      fprintf(stderr, "cant open Startscript %s for write\n", mp_ptr->startscript);
