@@ -24,6 +24,7 @@
  */
 
 /* revision history:
+ * version 2.1.0a;   2004/06/03   hof: added onionskin ref_mode
  * version 1.3.16c;  2003.07.08   hof: created (as extract of the gap_onion_worker.c module)
  */
 
@@ -265,6 +266,9 @@ gap_onion_base_onionskin_apply(gpointer gpp
              , GapOnionBaseFptrFindFrameInImageCache fptr_find_frame_in_img_cache
              , gboolean use_cache)
 {
+  gint32        l_nr;
+  gint32        l_sign;
+  
   gint32        l_onr;
   gint32        l_ign;
   gint32        l_idx;
@@ -280,12 +284,14 @@ gap_onion_base_onionskin_apply(gpointer gpp
   gint        l_nlayers;
   gdouble     l_opacity;
   char       *l_layername;
+  gint32      l_active_layer;
 
 
   if(gap_debug)
   {
      printf("gap_onion_base_onionskin_apply: START\n");
      printf("  num_olayers: %d\n",   (int)vin_ptr->num_olayers);
+     printf("  ref_mode:  %d\n",     (int)vin_ptr->ref_mode);
      printf("  ref_delta: %d\n",     (int)vin_ptr->ref_delta);
      printf("  ref_cycle: %d\n",     (int)vin_ptr->ref_cycle);
      printf("  stack_pos: %d\n",     (int)vin_ptr->stack_pos);
@@ -305,6 +311,22 @@ gap_onion_base_onionskin_apply(gpointer gpp
 
   }
 
+  /* keep information about the active_layer
+   * (needed for restore after onionskin layers were recreated)
+   */
+  l_active_layer = gimp_image_get_active_layer(image_id);
+  if(l_active_layer >= 0)
+  {
+    if(gap_onion_base_check_is_onion_layer(l_active_layer))
+    {
+      /* no need to remember the active layer, because
+       * it is an onionskin layer that will be deleted
+       * before recreation
+       */
+      l_active_layer = -1;
+    }
+  }
+  
   /* delete onion layers (if there are old ones) */
   gap_onion_base_onionskin_delete(image_id);
 
@@ -323,21 +345,39 @@ gap_onion_base_onionskin_apply(gpointer gpp
   l_opacity = vin_ptr->opacity;
   l_new_filename = NULL;
   l_frame_nr = ainfo_curr_frame_nr;
+  l_sign = -1;
   for(l_onr=1; l_onr <= vin_ptr->num_olayers; l_onr++)
   {
     /* find out reference frame number */
+
     if(vin_ptr->asc_opacity)
     {
        /* process far neigbours first to give them the highest configured opacity value */
-       l_frame_nr = ainfo_curr_frame_nr
-                  + (vin_ptr->ref_delta * ((1+ vin_ptr->num_olayers) - l_onr));
+       l_nr = (1+ vin_ptr->num_olayers) - l_onr;
     }
     else
     {
        /* process near neigbours first to give them the highest configured opacity value */
-       l_frame_nr = ainfo_curr_frame_nr
-                  + (vin_ptr->ref_delta * l_onr);
+       l_nr = l_onr;
     }
+ 
+    /* find out reference frame number */
+    switch(vin_ptr->ref_mode)
+    {
+      case GAP_ONION_REFMODE_BIDRIECTIONAL_SINGLE:
+        l_sign *= -1; /* toggle sign between -1 and +1 */
+        break;
+      case GAP_ONION_REFMODE_BIDRIECTIONAL_DOUBLE:
+        l_sign *= -1; /* toggle sign between -1 and +1 */
+	l_nr = 1 + ((l_nr -1) / 2);
+        break;
+      case GAP_ONION_REFMODE_NORMAL:
+        l_sign = 1;  /* normal mode: always force sign of +1 */
+      default:
+        break;
+    }
+ 
+    l_frame_nr = ainfo_curr_frame_nr + (l_sign * (vin_ptr->ref_delta * l_nr));
 
 
     if(!vin_ptr->ref_cycle)
@@ -401,7 +441,9 @@ gap_onion_base_onionskin_apply(gpointer gpp
       /* dont waste time and memory for undo in noninteracive processing
        * of the src frames
        */
-      gimp_image_undo_enable(l_tmp_image_id); /* clear undo stack */
+      /*gimp_image_undo_enable(l_tmp_image_id);*/ /* clear undo stack */
+      /* no more gimp_image_undo_enable, causes warnings since gimp-2.1.6 */
+      /*  Gimp-Core-CRITICAL **: file gimpimage.c: line 1708 (gimp_image_undo_thaw): assertion `gimage->undo_freeze_count > 0' failed */
       gimp_image_undo_disable(l_tmp_image_id); /*  NO Undo */
     }
     else
@@ -540,7 +582,123 @@ gap_onion_base_onionskin_apply(gpointer gpp
     if(l_new_filename) { g_free(l_new_filename); l_new_filename = NULL; };
 
   }
+
+  if(l_active_layer >= 0)
+  {
+    gimp_image_set_active_layer(image_id, l_active_layer);
+  }
+
   if(gap_debug) printf("gap_onion_base_onionskin_apply: END\n\n");
 
   return 0;
 }       /* end gap_onion_base_onionskin_apply */
+
+
+/* ----------------------------------
+ * gap_onion_image_has_oinonlayers
+ * ----------------------------------
+ * check if image has onionskin layers
+ * IN: only_visible TRUE check only for visible onionskin layers
+ *                  FALSE check for all onionskin layers
+ */
+gboolean
+gap_onion_image_has_oinonlayers(gint32 image_id, gboolean only_visible)
+{
+  gint32     *l_layers_list;
+  gint        l_nlayers;
+  gint        l_idx;
+  gint        l_is_onion;
+  gint32      l_layer_id;
+  gboolean    l_has_onion;
+
+  if(gap_debug)
+  {
+     printf("gap_onion_image_has_oinonlayers: START only_visible: %d image_id: %d\n"
+            , (int)only_visible
+	    , (int)image_id
+	    );
+  }
+
+  l_has_onion = FALSE;
+
+  l_layers_list = gimp_image_get_layers(image_id, &l_nlayers);
+  if(l_layers_list)
+  {
+    for(l_idx=0;l_idx < l_nlayers;l_idx++)
+    {
+      l_layer_id = l_layers_list[l_idx];
+      l_is_onion = gap_onion_base_check_is_onion_layer(l_layer_id);
+
+      if(l_is_onion)
+      {
+        if (only_visible)
+	{
+	  if(gimp_drawable_get_visible(l_layer_id))
+	  {
+            l_has_onion = TRUE;
+	    break;
+	  }
+	}
+	else
+        {
+          l_has_onion = TRUE;
+	  break;
+        }
+      }
+    }
+    
+    g_free(l_layers_list);
+  }
+  return (l_has_onion);
+
+}  /* end gap_onion_image_has_oinonlayers */
+
+
+/* ---------------------------------
+ * gap_onion_base_image_duplicate
+ * ---------------------------------
+ * duplicate the image 
+ * and mark onionskin layers in the copy 
+ */
+gint32
+gap_onion_base_image_duplicate(gint32 image_id)
+{
+  gint32 dup_image_id;
+  
+  dup_image_id = gimp_image_duplicate(image_id);
+  if(dup_image_id >= 0)
+  {
+    gint32     *l_layers_list;
+    gint32     *l_dup_layers_list;
+    gint        l_nlayers;
+    gint        l_dup_nlayers;
+    gint        l_idx;
+    gint        l_is_onion;
+    gint32      l_layer_id;
+    gboolean    l_has_onion;
+    
+    l_layers_list = gimp_image_get_layers(image_id, &l_nlayers);
+    l_dup_layers_list = gimp_image_get_layers(dup_image_id, &l_dup_nlayers);
+
+    if((l_layers_list) 
+    && (l_dup_layers_list))
+    {
+      for(l_idx=0;l_idx < MIN(l_nlayers, l_dup_nlayers);l_idx++)
+      {
+	l_layer_id = l_layers_list[l_idx];
+	l_is_onion = gap_onion_base_check_is_onion_layer(l_layer_id);
+
+	if(l_is_onion)
+	{
+	  gap_onion_base_mark_as_onionlayer(l_dup_layers_list[l_idx]);
+	}
+      }
+
+      g_free(l_layers_list);
+      g_free(l_dup_layers_list);
+    }
+    
+  }
+  
+  return(dup_image_id);
+}  /* end gap_onion_base_image_duplicate */
