@@ -42,7 +42,6 @@
 #include "config.h"
 
 /* SYSTEM (UNIX) includes */
-#include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
 #include <string.h>
@@ -53,6 +52,8 @@
 #include <sys/stat.h>
 #include <errno.h>
 
+#include <glib/gstdio.h>
+
 #ifdef G_OS_WIN32
 #include <io.h>
 #  ifndef S_ISDIR
@@ -295,7 +296,7 @@ p_copy_png_thumb(char *filename_src, char *filename_dst)
 					 );
               g_object_unref(pixbuf);
 	    }
-	    g_free(thumbnail);
+	    g_object_unref(thumbnail);
 	  }
           g_free(dst_png_thumb_full);
         }
@@ -450,7 +451,7 @@ gap_thumb_file_delete_thumbnail(char *filename)
         if(gap_lib_file_exists(png_thumb_full) == 1)
         {
           if (gap_debug) printf ("gap_thumb_file_delete_thumbnail: png_thumb_full: %s\n", png_thumb_full);
-          remove(png_thumb_full);
+          g_remove(png_thumb_full);
         }
         g_free(png_thumb_full);
       }
@@ -600,7 +601,7 @@ gap_thumb_file_load_pixbuf_thumbnail(char* filename
       *th_bpp = nchannels;
 
     }
-    g_free(thumbnail);
+    g_object_unref(thumbnail);
   }
 
   return (pixbuf);
