@@ -55,7 +55,6 @@
 
 /* Defines */
 #define PLUG_IN_NAME        "plug_in_wr_huesat"
-#define PLUG_IN_VERSION     "v1.3 (2004/01/15)"
 #define PLUG_IN_IMAGE_TYPES "RGB*, GRAY*"
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
@@ -258,8 +257,8 @@ query (void)
                           ,
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
-                          N_("<Image>/Video/Layer/Colors/Hue-Saturation..."),
+                          GAP_VERSION_WITH_DATE,
+                          N_("Hue-Saturation..."),
                           PLUG_IN_IMAGE_TYPES,
                           GIMP_PLUGIN,
                           nargs,
@@ -274,12 +273,23 @@ query (void)
                           "",
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
+                          GAP_VERSION_WITH_DATE,
                           NULL,    /* do not appear in menus */
                           NULL,
                           GIMP_PLUGIN,
                           nargs_iter, nreturn_iter,
                           args_iter, return_iter);
+
+  {
+    /* Menu names */
+    const char *menupath_image_video_layer_colors = N_("<Image>/Video/Layer/Colors/");
+
+    //gimp_plugin_menu_branch_register("<Image>", "Video");
+    //gimp_plugin_menu_branch_register("<Image>/Video", "Layer");
+    //gimp_plugin_menu_branch_register("<Image>/Video/Layer", "Colors");
+
+    gimp_plugin_menu_register (PLUG_IN_NAME, menupath_image_video_layer_colors);
+  }
 }
 
 
