@@ -51,14 +51,16 @@
 
 #include <config.h>
 
-#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
 #include <math.h>
+
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
+
 #include <libgimp/gimp.h>
 #include <gap_vid_api-intl.h>
 
